@@ -85,7 +85,7 @@ class TableTriggerBuilder(object):
     def create_trigger_sql(self):
         return (
             '''CREATE TRIGGER %(table_name)s_version_trigger
-            AFTER INSERT OR UPDATE OR DELETE ON %(table_name)s
+            AFTER INSERT OR UPDATE OR DELETE ON "%(table_name)s"
             FOR EACH ROW
             EXECUTE PROCEDURE create_%(table_name)s_history_record();
             ''' % dict(
